@@ -21,6 +21,16 @@ class TestDump2(unittest.TestCase, TestPOSCARoh):
         self.assertEqual(self.tmp_system.get_nframes(), 2)
         
         
+class TestDumpUnwrap(unittest.TestCase, TestPOSCARoh):
+    def setUp(self):
+        self.unwrap = True
+        self.system = dpdata.System(
+            os.path.join('poscars', 'conf_unfold.dump'),
+            type_map=['O', 'H'],
+            unwrap=self.unwrap,
+        )
+
+
 if __name__ == '__main__':
     unittest.main()
     
